# coding: utf-8

# flake8: noqa

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "CalendarApi",
    "CandlesApi",
    "GeneralApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "CalendarEvent",
    "Candle",
    "Info",
    "Metadata",
    "SearchResult",
]

# import apis into sdk package
from openapi_client.api.calendar_api import CalendarApi as CalendarApi
from openapi_client.api.candles_api import CandlesApi as CandlesApi
from openapi_client.api.general_api import GeneralApi as GeneralApi

# import ApiClient
from openapi_client.api_response import ApiResponse as ApiResponse
from openapi_client.api_client import ApiClient as ApiClient
from openapi_client.configuration import Configuration as Configuration
from openapi_client.exceptions import OpenApiException as OpenApiException
from openapi_client.exceptions import ApiTypeError as ApiTypeError
from openapi_client.exceptions import ApiValueError as ApiValueError
from openapi_client.exceptions import ApiKeyError as ApiKeyError
from openapi_client.exceptions import ApiAttributeError as ApiAttributeError
from openapi_client.exceptions import ApiException as ApiException

# import models into sdk package
from openapi_client.models.calendar_event import CalendarEvent as CalendarEvent
from openapi_client.models.candle import Candle as Candle
from openapi_client.models.info import Info as Info
from openapi_client.models.metadata import Metadata as Metadata
from openapi_client.models.search_result import SearchResult as SearchResult




# coding: utf-8

# flake8: noqa
"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from tickcatcher.models.calendar_event import CalendarEvent
from tickcatcher.models.candle import Candle
from tickcatcher.models.info import Info
from tickcatcher.models.metadata import Metadata
from tickcatcher.models.search_result import SearchResult




# flake8: noqa

# import apis into api package
from tickcatcher.api.calendar_api import CalendarApi
from tickcatcher.api.candles_api import CandlesApi
from tickcatcher.api.general_api import GeneralApi




# coding: utf-8

# flake8: noqa
"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from openapi_client.models.calendar_event import CalendarEvent
from openapi_client.models.candle import Candle
from openapi_client.models.info import Info
from openapi_client.models.metadata import Metadata
from openapi_client.models.search_result import SearchResult




# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List
from typing import Optional, Set
from typing_extensions import Self

class Info(BaseModel):
    """
    Info
    """ # noqa: E501
    package_name: StrictStr = Field(description="The package that you are using.", alias="packageName")
    usable_coins: List[StrictStr] = Field(description="The usable coins list for your package.", alias="usableCoins")
    max_candles_on_request: StrictInt = Field(description="Maximum allowed candles for your package to fetch at one query.", alias="maxCandlesOnRequest")
    usable_timeframes: List[StrictStr] = Field(description="The timeframes that you can select on your queries.", alias="usableTimeframes")
    custom_date_selection: StrictBool = Field(description="Whether you can select start and end dates during queries.", alias="customDateSelection")
    __properties: ClassVar[List[str]] = ["packageName", "usableCoins", "maxCandlesOnRequest", "usableTimeframes", "customDateSelection"]

    @field_validator('package_name')
    def package_name_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['Basic', 'Pro', 'Ultra', 'Mega', 'Enterprise']):
            raise ValueError("must be one of enum values ('Basic', 'Pro', 'Ultra', 'Mega', 'Enterprise')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Info from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Info from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "packageName": obj.get("packageName"),
            "usableCoins": obj.get("usableCoins"),
            "maxCandlesOnRequest": obj.get("maxCandlesOnRequest"),
            "usableTimeframes": obj.get("usableTimeframes"),
            "customDateSelection": obj.get("customDateSelection")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "CalendarApi",
    "CandlesApi",
    "GeneralApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "CalendarEvent",
    "Candle",
    "Info",
    "Metadata",
    "SearchResult",
]

# import apis into sdk package
from tickcatcher.api.calendar_api import CalendarApi as CalendarApi
from tickcatcher.api.candles_api import CandlesApi as CandlesApi
from tickcatcher.api.general_api import GeneralApi as GeneralApi

# import ApiClient
from tickcatcher.api_response import ApiResponse as ApiResponse
from tickcatcher.api_client import ApiClient as ApiClient
from tickcatcher.configuration import Configuration as Configuration
from tickcatcher.exceptions import OpenApiException as OpenApiException
from tickcatcher.exceptions import ApiTypeError as ApiTypeError
from tickcatcher.exceptions import ApiValueError as ApiValueError
from tickcatcher.exceptions import ApiKeyError as ApiKeyError
from tickcatcher.exceptions import ApiAttributeError as ApiAttributeError
from tickcatcher.exceptions import ApiException as ApiException

# import models into sdk package
from tickcatcher.models.calendar_event import CalendarEvent as CalendarEvent
from tickcatcher.models.candle import Candle as Candle
from tickcatcher.models.info import Info as Info
from tickcatcher.models.metadata import Metadata as Metadata
from tickcatcher.models.search_result import SearchResult as SearchResult




# flake8: noqa

# import apis into api package
from openapi_client.api.calendar_api import CalendarApi
from openapi_client.api.candles_api import CandlesApi
from openapi_client.api.general_api import GeneralApi




# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class CalendarEvent(BaseModel):
    """
    CalendarEvent
    """ # noqa: E501
    title: StrictStr
    country: StrictStr
    indicator: Optional[StrictStr] = None
    ticker: Optional[StrictStr] = None
    comment: Optional[StrictStr] = None
    category: Optional[StrictStr] = None
    period: Optional[StrictStr] = None
    reference_date: Optional[StrictStr] = None
    source: Optional[StrictStr] = None
    source_url: Optional[StrictStr] = None
    actual: Optional[Union[StrictFloat, StrictInt]] = None
    previous: Optional[Union[StrictFloat, StrictInt]] = None
    forecast: Optional[Union[StrictFloat, StrictInt]] = None
    actual_raw: Optional[Union[StrictFloat, StrictInt]] = None
    previous_raw: Optional[Union[StrictFloat, StrictInt]] = None
    forecast_raw: Optional[Union[StrictFloat, StrictInt]] = None
    currency: Optional[StrictStr] = None
    unit: Optional[StrictStr] = None
    importance: Union[StrictFloat, StrictInt] = Field(description="A number of importance, can be -1, 0 or 1.")
    ts: Union[StrictFloat, StrictInt] = Field(description="Unix timestamp (ms)")
    scale: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["title", "country", "indicator", "ticker", "comment", "category", "period", "reference_date", "source", "source_url", "actual", "previous", "forecast", "actual_raw", "previous_raw", "forecast_raw", "currency", "unit", "importance", "ts", "scale"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CalendarEvent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if indicator (nullable) is None
        # and model_fields_set contains the field
        if self.indicator is None and "indicator" in self.model_fields_set:
            _dict['indicator'] = None

        # set to None if ticker (nullable) is None
        # and model_fields_set contains the field
        if self.ticker is None and "ticker" in self.model_fields_set:
            _dict['ticker'] = None

        # set to None if comment (nullable) is None
        # and model_fields_set contains the field
        if self.comment is None and "comment" in self.model_fields_set:
            _dict['comment'] = None

        # set to None if category (nullable) is None
        # and model_fields_set contains the field
        if self.category is None and "category" in self.model_fields_set:
            _dict['category'] = None

        # set to None if period (nullable) is None
        # and model_fields_set contains the field
        if self.period is None and "period" in self.model_fields_set:
            _dict['period'] = None

        # set to None if reference_date (nullable) is None
        # and model_fields_set contains the field
        if self.reference_date is None and "reference_date" in self.model_fields_set:
            _dict['reference_date'] = None

        # set to None if source (nullable) is None
        # and model_fields_set contains the field
        if self.source is None and "source" in self.model_fields_set:
            _dict['source'] = None

        # set to None if source_url (nullable) is None
        # and model_fields_set contains the field
        if self.source_url is None and "source_url" in self.model_fields_set:
            _dict['source_url'] = None

        # set to None if actual (nullable) is None
        # and model_fields_set contains the field
        if self.actual is None and "actual" in self.model_fields_set:
            _dict['actual'] = None

        # set to None if previous (nullable) is None
        # and model_fields_set contains the field
        if self.previous is None and "previous" in self.model_fields_set:
            _dict['previous'] = None

        # set to None if forecast (nullable) is None
        # and model_fields_set contains the field
        if self.forecast is None and "forecast" in self.model_fields_set:
            _dict['forecast'] = None

        # set to None if actual_raw (nullable) is None
        # and model_fields_set contains the field
        if self.actual_raw is None and "actual_raw" in self.model_fields_set:
            _dict['actual_raw'] = None

        # set to None if previous_raw (nullable) is None
        # and model_fields_set contains the field
        if self.previous_raw is None and "previous_raw" in self.model_fields_set:
            _dict['previous_raw'] = None

        # set to None if forecast_raw (nullable) is None
        # and model_fields_set contains the field
        if self.forecast_raw is None and "forecast_raw" in self.model_fields_set:
            _dict['forecast_raw'] = None

        # set to None if currency (nullable) is None
        # and model_fields_set contains the field
        if self.currency is None and "currency" in self.model_fields_set:
            _dict['currency'] = None

        # set to None if unit (nullable) is None
        # and model_fields_set contains the field
        if self.unit is None and "unit" in self.model_fields_set:
            _dict['unit'] = None

        # set to None if scale (nullable) is None
        # and model_fields_set contains the field
        if self.scale is None and "scale" in self.model_fields_set:
            _dict['scale'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CalendarEvent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "title": obj.get("title"),
            "country": obj.get("country"),
            "indicator": obj.get("indicator"),
            "ticker": obj.get("ticker"),
            "comment": obj.get("comment"),
            "category": obj.get("category"),
            "period": obj.get("period"),
            "reference_date": obj.get("reference_date"),
            "source": obj.get("source"),
            "source_url": obj.get("source_url"),
            "actual": obj.get("actual"),
            "previous": obj.get("previous"),
            "forecast": obj.get("forecast"),
            "actual_raw": obj.get("actual_raw"),
            "previous_raw": obj.get("previous_raw"),
            "forecast_raw": obj.get("forecast_raw"),
            "currency": obj.get("currency"),
            "unit": obj.get("unit"),
            "importance": obj.get("importance"),
            "ts": obj.get("ts"),
            "scale": obj.get("scale")
        })
        return _obj





# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.calendar_event import CalendarEvent

class TestCalendarEvent(unittest.TestCase):
    """CalendarEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CalendarEvent:
        """Test CalendarEvent
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CalendarEvent`
        """
        model = CalendarEvent()
        if include_optional:
            return CalendarEvent(
                title = '',
                country = '',
                indicator = '',
                ticker = '',
                comment = '',
                category = '',
                period = '',
                reference_date = '',
                source = '',
                source_url = '',
                actual = 1.337,
                previous = 1.337,
                forecast = 1.337,
                actual_raw = 1.337,
                previous_raw = 1.337,
                forecast_raw = 1.337,
                currency = '',
                unit = '',
                importance = 1.337,
                ts = 1.337,
                scale = ''
            )
        else:
            return CalendarEvent(
                title = '',
                country = '',
                importance = 1.337,
                ts = 1.337,
        )
        """

    def testCalendarEvent(self):
        """Test CalendarEvent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.metadata import Metadata

class TestMetadata(unittest.TestCase):
    """Metadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Metadata:
        """Test Metadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Metadata`
        """
        model = Metadata()
        if include_optional:
            return Metadata(
                symbol = 'BTCUSDT',
                timeframe = '1h',
                first_candle = '2025-10-01T00:00:00.000Z',
                last_candle = '2025-10-15T00:00:00.000Z',
                total_candles = 816,
                completion_percent = '99.52',
                estimated_completion_date = '2025-10-20T00:00:00.000Z'
            )
        else:
            return Metadata(
                symbol = 'BTCUSDT',
                timeframe = '1h',
                first_candle = '2025-10-01T00:00:00.000Z',
                last_candle = '2025-10-15T00:00:00.000Z',
                total_candles = 816,
                completion_percent = '99.52',
                estimated_completion_date = '2025-10-20T00:00:00.000Z',
        )
        """

    def testMetadata(self):
        """Test Metadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
